(this.webpackJsonpst_mui_multiselect=this.webpackJsonpst_mui_multiselect||[]).push([[0],{22:function(e,t,n){e.exports=n(28)},28:function(e,t,n){"use strict";n.r(t);var a=n(4),o=n.n(a),r=n(8),s=n.n(r),l=n(0),c=n(1),i=n(2),u=n(3),p=n(16),d=n(53),m=function(e){Object(i.a)(n,e);var t=Object(u.a)(n);function n(){var e;Object(c.a)(this,n);for(var a=arguments.length,r=new Array(a),s=0;s<a;s++)r[s]=arguments[s];return(e=t.call.apply(t,[this].concat(r))).state={selectedOptions:[]},e.render=function(){var t=e.props.args.options,n=e.props.theme,a={};return n&&"dark"===n.base&&(a.color="#FAFAFA"),o.a.createElement(d.a,{labelId:"demo-mutiple-checkbox-label",id:"demo-mutiple-checkbox",style:a,multiple:!0,native:!0,value:e.state.selectedOptions,onChange:e.onChange,inputProps:{id:"select-multiple-native",size:e.props.args.size},disabled:e.props.disabled},t.map((function(e){return o.a.createElement("option",{key:e,value:e},e)})))},e.onChange=function(t){for(var n=t.target.options,a=[],o=0,r=n.length;o<r;o+=1)n[o].selected&&a.push(n[o].value);e.setState((function(e){return{selectedOptions:a}}),(function(){return p.a.setComponentValue(e.state.selectedOptions)}))},e}return Object(l.a)(n)}(p.b),b=Object(p.c)(m);s.a.render(o.a.createElement(o.a.StrictMode,null,o.a.createElement(b,null)),document.getElementById("root"))}},[[22,1,2]]]);
//# sourceMappingURL=main.1e2484a6.chunk.js.map
